@@ -54,6 +54,7 @@ sorted_classifiers: List[str] = [
     "Environment :: GPU :: NVIDIA CUDA :: 12",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.0",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.2",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -155,6 +156,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Lektor",
     "Framework :: Masonite",
     "Framework :: Matplotlib",
+    "Framework :: MkDocs",
     "Framework :: Nengo",
     "Framework :: Odoo",
     "Framework :: Odoo :: 8.0",
@@ -166,6 +168,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Odoo :: 14.0",
     "Framework :: Odoo :: 15.0",
     "Framework :: Odoo :: 16.0",
+    "Framework :: Odoo :: 17.0",
     "Framework :: Opps",
     "Framework :: Paste",
     "Framework :: Pelican",
